@@ -1,4 +1,7 @@
+# flake8: noqa
+
+
+from .filters_enums import *
 from .item_types import ItemTypeGC
 from .loadout_slots import LoadoutSlot
-from .filters_enums import TagsInternalName
-from .teams import TeamSide
\ No newline at end of file
+from .teams import TeamSide
